#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

""" mash module of flr """

import flr
import subprocess

# Base mash command
MASH_CMD = "/usr/bin/mash"


def mash(conf, conf_file=None, out_dir=None,
         compsfile=None, prev=None, delta=None, no_delta=None):
    """
    Run mash with provided params

    :param conf: str, configuration to build
    :param conf_file: str, config file to use
    :param out_dir: str, the path to place output
    :param compsfile: str, comps file to use
    :param prev: str, previous mash run to use as a basis for createrepo
    :param delta: str, previous directory to use for deltarpm creation
    :param no_delta: bool, do not compose deltarpms
    """

    cmd = [
        MASH_CMD,
    ]

    if conf_file:
        cmd.append("-c {0}".format(conf_file))

    if conf_file:
        cmd.append("-o {0}".format(out_dir))

    if compsfile:
        cmd.append("-f {0}".format(compsfile))

    if prev:
        cmd.append("-p {0}".format(prev))

    if delta:
        cmd.append("-d {0}".format(delta))

    if no_delta:
        cmd.append("--no-delta")

    cmd.append(conf)

    flr.log.info("Running command: {0}".format(' '.join(cmd)))
    subprocess.call(cmd)


# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
