#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

""" utils module of flr """

import sys
import flr
import subprocess

def subproc_call(cmd, log_msg=None, ignore_failure=False):
    """
    subprocess.call wrapper with logging and error handling

    :param cmd:     list, command to pass to subprocess.call
    :param log_msg: str, info level log message
    :return:        bool, false = command non-zero exit, true = zero exit code
    """

    # Log
    if log_msg:
        flr.log.info(log_msg)

    # Check return code, raise exception if failure occurs
    if subprocess.call(cmd):
        flr.log.error("COMMAND FAILED: {}".format(cmd))
        if ignore_failure:
            return False
        else:
            raise RuntimeError("Command returned non-zero: {}".format(cmd))

    # If we get here, it's been successful
    return True

def subproc_popen(cmd, log_msg=None):
    """
    subprocess.Popen wrapper with logging and error handling

    :param cmd:     list, command to pass to subprocess.Popen
    :param log_msg: str, info level log message

    :return: (stdout, stderr)
    """

    # Log
    if log_msg:
        flr.log.info(log_msg)

    # Run command
    subproc = subprocess.Popen(
        cmd,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE
    )

    # Get output
    stdout, stderr = subproc.communicate()

    # Check return code, raise exception if failure occurs
    if subproc.returncode:
        flr.log.error("COMMAND FAILED: {}".format(cmd))
        flr.log.error("COMMAND STDOUT: {}".format(stdout))
        flr.log.error("COMMAND STDERR: {}".format(stderr))
        raise RuntimeError("Command returned non-zero: {}".format(cmd))

    return (stdout, stderr)

# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
